@@ -285,6 +285,15 @@ class SledPretrainedModel(PreTrainedModel, metaclass=abc.ABCMeta):
                     f'probably due to config_overrides. Setting the underlying config to match SLEDs')
                 for k in inconsistent_keys:
                     setattr(self.underlying_model.config, k, getattr(self.config, k))
+
+            config = self.config
+            if  self._window_fraction != config.window_fraction or \
+                    self._context_size != config.context_size or\
+                    self._window_margin != int(config.context_size * (1 - config.window_fraction) / 2) or \
+                    self._sliding_method != config.sliding_method:
+                raise RuntimeError('SLED does not support changing its configuration after it is initialized. '
+                                   'Try reloading the model with overrides')
+
             self._verified_config_consistency = True
 
     @property
@@ -648,6 +657,12 @@ class SledModel(SledPretrainedModel):
         forward_kwargs["return_dict"] = return_dict
         forward_kwargs["labels"] = labels
         self._fix_post_encoding()
+        if 'decoder_input_ids' in self._forward_kwargs_names and \
+            forward_kwargs.get('decoder_input_ids', None) is None and \
+                hasattr(self, 'prepare_decoder_input_ids_from_labels') :
+            logger.warning('Passing a batch through the model without the decoder_input_ids is likely to cause issues. '
+                           'If you encounter cuda errors, make sure you use the prepare_decoder_input_ids_from_labels '
+                           'function of the model correctly before passing the input')
         res = self._underlying_model.forward(
             *args, **_extract_keyword_args(forward_kwargs, self._forward_kwargs_names)
         )
